import { DependabotAlert } from './alert'

type SecurityVulnerability = DependabotAlert['security_vulnerability']

export interface Vulnerability {
  /**
   * The first version containing a fix for the vulnerability
   */
  firstPatchedVersion?: string
  /**
   * A string that describes the vulnerable package versions.
   * This string follows a basic syntax with a few forms.
   * + `= 0.2.0` denotes a single vulnerable version.
   * + `<= 1.0.8` denotes a version range up to and including the specified version
   * + `< 0.1.11` denotes a version range up to, but excluding, the specified version
   * + `>= 4.3.0, < 4.3.5` denotes a version range with a known minimum and maximum version.
   * + `>= 0.0.1` denotes a version range with a known minimum, but no known maximum
   */
  vulnerableVersionRange: string
}

export const toVulnerability = (
  securityVulnerability: SecurityVulnerability,
): Vulnerability => ({
  firstPatchedVersion: securityVulnerability.first_patched_version?.identifier,
  vulnerableVersionRange: securityVulnerability.vulnerable_version_range,
})
